pub enum Range {
Full,
From {
first_byte_pos: u64,
},
Inclusive {
first_byte_pos: u64,
last_byte_pos: u64,
},
Suffix {
len: u64,
},
}Expand description
Variants
Full
A range that requests the full range of bytes from a resource.
From
A range that requests a subset of bytes from a resource, first_byte_pos <= x.
Inclusive
A range that requests a subset of bytes from a resource, first_byte_pos <= x && x <= last_byte_pos.
Suffix
A range that requests a subset of bytes from the end of the resource, or total - len <= x.
Implementations
Sourceimpl Range
impl Range
Sourcepub fn from_http_range_header(header: &HeaderValue) -> Result<Self, Error>
pub fn from_http_range_header(header: &HeaderValue) -> Result<Self, Error>
Parse an HTTP Range header according to RFC-7233.
pub fn to_http_request_header(&self) -> Option<HeaderValue>