pub struct RepoKeys { /* private fields */ }Expand description
Hold all the private keys for a repository.
Implementations
Sourceimpl RepoKeys
impl RepoKeys
Sourcepub fn generate(dir: &Path) -> Result<Self, ParseError>
pub fn generate(dir: &Path) -> Result<Self, ParseError>
Generates a set of [RoleKey]s, writing the following files to the passed dir:
- root.json
- targets.json
- snapshot.json
- timestamp.json
Returns the generated RepoKeys struct.
Sourcepub fn builder() -> RepoKeysBuilder
pub fn builder() -> RepoKeysBuilder
Return a RepoKeysBuilder.
Sourcepub fn from_dir(path: &Path) -> Result<Self, ParseError>
pub fn from_dir(path: &Path) -> Result<Self, ParseError>
Create a RepoKeys from a pm-style keys directory, which can optionally contain the following files:
- root.json - all the root metadata private keys.
- targets.json - all the targets metadata private keys.
- snapshot.json - all the snapshot metadata private keys.
- timestamp.json - all the timestamp metadata private keys.
Sourcepub fn root_keys(&self) -> &[Box<dyn PrivateKey>]
pub fn root_keys(&self) -> &[Box<dyn PrivateKey>]
Return all the loaded PrivateKeys for the root metadata.
Sourcepub fn targets_keys(&self) -> &[Box<dyn PrivateKey>]
pub fn targets_keys(&self) -> &[Box<dyn PrivateKey>]
Return all the loaded PrivateKeys for the targets metadata.
Sourcepub fn snapshot_keys(&self) -> &[Box<dyn PrivateKey>]
pub fn snapshot_keys(&self) -> &[Box<dyn PrivateKey>]
Return all the loaded PrivateKeys for the snapshot metadata.
Sourcepub fn timestamp_keys(&self) -> &[Box<dyn PrivateKey>]
pub fn timestamp_keys(&self) -> &[Box<dyn PrivateKey>]
Return all the loaded PrivateKeys for the timestamp metadata.