pub struct RepoKeysBuilder { /* private fields */ }Expand description
Helper to construct RepoKeys.
Implementations
Sourceimpl RepoKeysBuilder
impl RepoKeysBuilder
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new RepoKeysBuilder.
Sourcepub fn add_root_key(self, key: Box<dyn PrivateKey>) -> Self
pub fn add_root_key(self, key: Box<dyn PrivateKey>) -> Self
Add a PrivateKey that will be used as a root key.
Sourcepub fn add_targets_key(self, key: Box<dyn PrivateKey>) -> Self
pub fn add_targets_key(self, key: Box<dyn PrivateKey>) -> Self
Add a PrivateKey that will be used as a targets key.
Sourcepub fn add_snapshot_key(self, key: Box<dyn PrivateKey>) -> Self
pub fn add_snapshot_key(self, key: Box<dyn PrivateKey>) -> Self
Add a PrivateKey that will be used as a snapshot key.
Sourcepub fn add_timestamp_key(self, key: Box<dyn PrivateKey>) -> Self
pub fn add_timestamp_key(self, key: Box<dyn PrivateKey>) -> Self
Add a PrivateKey that will be used as a timestamp key.
Sourcepub fn load_root_keys(self, path: &Path) -> Result<Self, ParseError>
pub fn load_root_keys(self, path: &Path) -> Result<Self, ParseError>
Load root metadata PrivateKeys from a pm-style json file.
Sourcepub fn load_targets_keys(self, path: &Path) -> Result<Self, ParseError>
pub fn load_targets_keys(self, path: &Path) -> Result<Self, ParseError>
Load targets metadata PrivateKeys from a pm-style json file.
Sourcepub fn load_snapshot_keys(self, path: &Path) -> Result<Self, ParseError>
pub fn load_snapshot_keys(self, path: &Path) -> Result<Self, ParseError>
Load snapshot metadata PrivateKeys from a pm-style json file.
Sourcepub fn load_timestamp_keys(self, path: &Path) -> Result<Self, ParseError>
pub fn load_timestamp_keys(self, path: &Path) -> Result<Self, ParseError>
Load timestamp metadata PrivateKeys from a pm-style json file.
pub fn build(self) -> RepoKeys