pub enum CopyMode {
Copy,
CopyOverwrite,
HardLink,
}Expand description
Describes how package blobs should be copied into the repository.
Variants
Copy
Copy package blobs into the repository. This will skip copying the blob if it already exists in the repository.
This will create a Copy-on-Write (reflink) on file systems that support it.
CopyOverwrite
Copy package blobs into the repository. This will overwrite a blob if it already exists in the repository.
This will create a Copy-on-Write (reflink) on file systems that support it.
HardLink
Create hard links from the package blobs into the repository.