pub struct Resource {
pub content_range: ContentRange,
pub stream: BoxStream<'static, Result<Bytes>>,
}Expand description
Fields
content_range: ContentRangeThe range in bytes available for this resource.
stream: BoxStream<'static, Result<Bytes>>A stream of bytes representing the resource.
Implementations
Sourceimpl Resource
impl Resource
Sourcepub fn content_len(&self) -> u64
pub fn content_len(&self) -> u64
The length of the content in bytes in the stream. This may be smaller than the total length of the file.
Sourcepub fn total_len(&self) -> u64
pub fn total_len(&self) -> u64
The total length of the file range in bytes. This may be larger than the bytes in the stream.
pub async fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<(), Error>