pub enum ContentRange {
Full {
complete_len: u64,
},
Inclusive {
first_byte_pos: u64,
last_byte_pos: u64,
complete_len: u64,
},
}Expand description
ContentRange denotes the size of a [Resource].
This mostly matches the semantics of the http Content-Range header according to RFC-7233, but we require that the complete length of the resource must be known.
Variants
Full
Denotes that the resource contains the full range of bytes.
Inclusive
Denotes that the resource contains a partial range of bytes between start >= x && x <= end,
inclusive.
Implementations
Sourceimpl ContentRange
impl ContentRange
Sourcepub fn from_http_content_length_header(
header: &HeaderValue,
) -> Result<Self, Error>
pub fn from_http_content_length_header( header: &HeaderValue, ) -> Result<Self, Error>
Parse an HTTP Content-Length header according to RFC-7230.
Sourcepub fn from_http_content_range_header(
header: &HeaderValue,
) -> Result<Self, Error>
pub fn from_http_content_range_header( header: &HeaderValue, ) -> Result<Self, Error>
Parse an HTTP Content-Range header according to RFC-7233.
Sourcepub fn content_len(&self) -> u64
pub fn content_len(&self) -> u64
Return the content length of the range, which may be smaller than the total length of the range.
pub fn to_http_content_range_header(&self) -> Option<HeaderValue>