pub struct FileSystemRepositoryBuilder { /* private fields */ }Expand description
A builder to create a repository contained on the local file system.
Implementations
Sourceimpl FileSystemRepositoryBuilder
impl FileSystemRepositoryBuilder
Sourcepub fn new(metadata_repo_path: Utf8PathBuf, blob_repo_path: Utf8PathBuf) -> Self
pub fn new(metadata_repo_path: Utf8PathBuf, blob_repo_path: Utf8PathBuf) -> Self
Creates a FileSystemRepositoryBuilder where the TUF metadata is stored in
metadata_repo_path, and the blobs are stored in blob_repo_path.
Sourcepub fn copy_mode(self, copy_mode: CopyMode) -> Self
pub fn copy_mode(self, copy_mode: CopyMode) -> Self
Select which CopyMode to use when copying files into the repository.
Sourcepub fn alias(self, alias: String) -> Self
pub fn alias(self, alias: String) -> Self
alias this repository to this name when this repository is registered on a target.
Sourcepub fn aliases(self, aliases: impl IntoIterator<Item = String>) -> Self
pub fn aliases(self, aliases: impl IntoIterator<Item = String>) -> Self
alias this repository to these names when this repository is registered on a target.
Sourcepub fn delivery_blob_type(self, delivery_blob_type: DeliveryBlobType) -> Self
pub fn delivery_blob_type(self, delivery_blob_type: DeliveryBlobType) -> Self
Set the type of delivery blob to generate when copying blobs into the repository.
Sourcepub fn blob_repo_path(self, blob_repo_path: Utf8PathBuf) -> Self
pub fn blob_repo_path(self, blob_repo_path: Utf8PathBuf) -> Self
Set the path to the blob repo.
Sourcepub fn build(self) -> FileSystemRepository
pub fn build(self) -> FileSystemRepository
Build a FileSystemRepository.